@@ -181,6 +181,10 @@
 #'
 #' N = 300
 #' set.seed(123)
+#' 
+#' if (!identical(tolower(Sys.getenv("NOT_CRAN")), "true")){
+#' Sys.setenv(OMP_THREAD_LIMIT = "2")
+#' }
 #'
 #' # generate binary treatments
 #' treatment = rbinom(N, 1, 0.5)
@@ -689,7 +693,7 @@ spmtree = function(formula,
     }else{
         splitvar_include = NULL
     }
-    tree_txt = print.dipm(tree_txt, X, Y, C, treatment,
+    tree_txt = print_dipm(tree_txt, X, Y, C, treatment,
                         types, ncat, method, ntree, print,
                         splitvar_include)
     if(prune){
